# BMA 2019 Ex Vivo (Brain Space 2)

Authors: Alexander Woodward<sup>1</sup>*, Rui Gong<sup>1</sup>, Ken Nakae<sup>2</sup>, Junichi Hata<sup>3,4,5</sup>, Hideyuki Okano<sup>3,4</sup>, Shin Ishii<sup>2</sup>, Yoko Yamaguchi<sup>6,7,8</sup>

1. Connectome Analysis Unit, Integrative Computational Brain Science Collaboration Division, RIKEN Center for Brain Science
2. Integrated Systems Biology Laboratory (Ishii Laboratory), Division of Systems Informatics, Department of Systems Science, Graduate School of Informatics, Kyoto University
3. Laboratory for Marmoset Neural Architecture, RIKEN Center for Brain Science
4. Department of Physiology (Okano Lab), Keio University School of Medicine, Keio University School of Medicine
5. Division of Regenerative Medicine, Jikei University School of Medicine
6. Applied Electronics Laboratory, Kanazawa Institute of Technology
7. Graduate School of Information Science and Technology, The University Tokyo
8. Laboratory for Cognitive Brain Mapping, RIKEN Center for Brain Science

*corresponding author: Alexander Woodward (alexander.woodward@riken.jp)

## DATASET DESCRIPTION

This atlas is composed of a population average ex-vivo MRI T2WI contrast mapped with the [BMA 2017 Ex Vivo](https://dataportal.brainminds.jp/reference-atlas-data/) (published by Woodward et al. [The Brain/MINDS 3D digital marmoset brain atlas](https://www.nature.com/articles/sdata20189)).
The population average MRI was constructed based on scans of 25 individual brains. The 25 brains were aligned with one another by iteratively applying linear and non-linear registration and averaging the transformation files until convergence. Data of individual brains were then resampled with an isotropic spatial resolution of 100×100×100µm3 and averaged across brain. The registration procedure gave a brain shape with a high signal-to-noise ratio compared to an individual MRI scan. The average MRI was then AC-PC aligned within an RAS (Right-Anterior-Superior) coordinate system.
Cortical flat map and mid-thickness surfaces for the left and right hemispheres are now provided in the common GIFTI format (*. gii) for surface data. These are compatible with [Connectome Workbench](https://www.humanconnectome.org/software/connectome-workbench) (version 1.5.0 and higher) and a Scene file is also provided for easy viewing of the data.
KEYWORDS : digital atlas, marmoset, Callithrix jacchus, brain, reference atlas, 3D, NIfTI, brain atlas, 3D Slicer, flat map, GIfTI, Connectome Workbench

## CITATION

Woodward, Alexander; Gong, Rui; Nakae, Ken; Hata, Junichi; Okano, Hideyuki; Ishii, Shin; Yamaguchi, Yoko : Brain/MINDS 3D Marmoset Reference Brain Atlas 2019 (DataID: 4520) https://doi.org/10.24475/bma.4520

## LICENSE

This work is licensed under a [Creative Commons Attribution 4.0 International License](http://creativecommons.org/licenses/by/4.0/).

## CONTENT

| File name | Description |
| ---- | ---- |
|[`bma_2019_exvivo`](bma_2019_exvivo)/|Initial package|
|&#x00A0;&#x00A0;[`CHANGES.txt`](bma_2019_exvivo/CHANGES.txt)|Change log|
|&#x00A0;&#x00A0;&#x00A0;&#x00A0;[`base_data/`](bma_2019_exvivo/base_data/)||
|&#x00A0;&#x00A0;&#x00A0;&#x00A0;&#x00A0;&#x00A0;[`sp2_avg_mri_exvivo_t2wi_v1.0.0.nii.gz`](bma_2019_exvivo/base_data/sp2_avg_mri_exvivo_t2wi_v1.0.0.nii.gz)|Population average ex-vivo MRI T2WI N=25|
|&#x00A0;&#x00A0;&#x00A0;&#x00A0;[`labelmap/`](bma_2019_exvivo/labelmap/)||
|&#x00A0;&#x00A0;&#x00A0;&#x00A0;&#x00A0;&#x00A0;[`sp2_label_512_3dslicer_v1.0.0.ctbl`](bma_2019_exvivo/labelmap/sp2_label_512_3dslicer_v1.0.0.ctbl)|Color look-up table|
|&#x00A0;&#x00A0;&#x00A0;&#x00A0;&#x00A0;&#x00A0;[`sp2_label_512_v1.0.0.nii.gz`](bma_2019_exvivo/labelmap/sp2_label_512_v1.0.0.nii.gz)|Atlas region label map|
|&#x00A0;&#x00A0;&#x00A0;&#x00A0;[`transforms/`](bma_2019_exvivo/transforms/)||
|&#x00A0;&#x00A0;&#x00A0;&#x00A0;&#x00A0;&#x00A0;[`sp1_to_sp2_affine_v1.0.0.txt`](bma_2019_exvivo/transforms/sp1_to_sp2_affine_v1.0.0.txt)|Linear part of transformation between BMA 2017 (brain space 1) and BMA 2019 (brain space 2). Affine matrix.|
|&#x00A0;&#x00A0;&#x00A0;&#x00A0;&#x00A0;&#x00A0;[`sp1_to_sp2_invwarp_v1.0.0.nii.gz`](bma_2019_exvivo/transforms/sp1_to_sp2_invwarp_v1.0.0.nii.gz)|Inverse of non-linear part of transformation between BMA 2017 (brain space 1) and BMA 2019 (brain space 2). Displacement field.|
|&#x00A0;&#x00A0;&#x00A0;&#x00A0;&#x00A0;&#x00A0;[`sp1_to_sp2_warp_v1.0.0.nii.gz`](bma_2019_exvivo/transforms/sp1_to_sp2_warp_v1.0.0.nii.gz)|Non-linear part of transformation between BMA 2017 (brain space 1) and BMA 2019 (brain space 2). Displacement field.|
|[`bma_sp2_cortical_flatmaps`](bma_sp2_cortical_flatmaps)|Flat map package|
|&#x00A0;&#x00A0;[`CHANGES.txt`](bma_sp2_cortical_flatmaps/CHANGES.txt)|Change log|
|&#x00A0;&#x00A0;[`bma_sp2.lh.cortex.label.gii`](bma_sp2_cortical_flatmaps/bma_sp2.lh.cortex.label.gii)|Left hemisphere cortex region label|
|&#x00A0;&#x00A0;[`bma_sp2.lh.flatmap.surf.gii`](bma_sp2_cortical_flatmaps/bma_sp2.lh.flatmap.surf.gii)|Left hemisphere cortical flat map|
|&#x00A0;&#x00A0;[`bma_sp2.lh.graymid.surf.gii`](bma_sp2_cortical_flatmaps/bma_sp2.lh.graymid.surf.gii)|Left hemisphere cortical mid-thickness surface|
|&#x00A0;&#x00A0;[`bma_sp2.rh.cortex.label.gii`](bma_sp2_cortical_flatmaps/bma_sp2.rh.cortex.label.gii)|Right hemisphere cortex region label|
|&#x00A0;&#x00A0;[`bma_sp2.rh.flatmap.surf.gii`](bma_sp2_cortical_flatmaps/bma_sp2.rh.flatmap.surf.gii)|Right hemisphere cortical flat map|
|&#x00A0;&#x00A0;[`bma_sp2.rh.graymid.surf.gii`](bma_sp2_cortical_flatmaps/bma_sp2.rh.graymid.surf.gii)|Right hemisphere cortical mid-thickness surface|
|&#x00A0;&#x00A0;[`bma_sp2_connectome_workbench.scene`](bma_sp2_cortical_flatmaps/bma_sp2_connectome_workbench.scene)|Connectome workbench scene file|
|&#x00A0;&#x00A0;[`bma_sp2_connectome_workbench.spec`](bma_sp2_cortical_flatmaps/bma_sp2_connectome_workbench.spec)|Connectome workbench specification file|

## VERSION HISTORY

* 17-06-2021: Added Flat map package.
* 04-02-2020: Initial release.

